@@ -1,4 +1,4 @@
-"print.variogram" <-
+"print.gstatVariogram" <-
 function(x, ...)
 {
 	print(data.frame(x), ...)
